File Input/Output and ``matrix``\ es
:::::::::::::::::::::::::::::::::::::::

.. toctree::
   :maxdepth: 3

   intro.rst
   Streams.rst
   File_input.rst
   File_output.rst
   Parsing_input.rst
   Parsing_numbers.rst
   The_Set_data_structure.rst
   apmatrix.rst
   A_distance_matrix.rst
   A_proper_distance_matrix.rst
   Glossary.rst
   Exercises.rst
   mixed_up_code.rst
   coding_practice.rst
